# -*- coding: utf-8 -*-
from setuphelpers import *
import json

"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

# Default arguments : addcontextmenufiles,addcontextmenufolders,addtopath,associatewithfiles,!desktopicon,!quicklaunchicon,!runcode
Previous silent_args = '/verysilent /mergetasks="!addcontextmenufiles,!addcontextmenufolders,addtopath,associatewithfiles,!desktopicon,!quicklaunchicon,!runcode"'

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_contains = "VSCodiumSetup-"
silent_args = '/verysilent /mergetasks="!runcode"'


def install():
    # Declaring local variables
    package_version = control.get_software_version()
    bin_name = glob.glob("*%s*.exe" % bin_contains)[0]
    app_uninstallkey = "{763CBF88-25C6-4B10-952F-326AE657F16B}_is1"

    # Uninstalling older versions of the software
    for to_uninstall in installed_softwares("VSCodium"):
        if Version(to_uninstall["version"]) < Version(package_version) or force:
            print("Removing: %s (%s)" % (to_uninstall["name"], to_uninstall["version"]))
            killalltasks(control.get_impacted_process_list())
            run(uninstall_cmd(to_uninstall["key"]))
            wait_uninstallkey_absent(to_uninstall["key"])

    # Installing the software
    print("Installing: %s" % bin_name)
    install_exe_if_needed(
        bin_name,
        silentflags=silent_args,
        key=app_uninstallkey,
        min_version=package_version,
    )


def session_setup():
    print("Disabling: Telemetry, automatic updates, surveys")

    # Configuration procedure: https://supunkavinda.blog/vscode-editing-settings-json
    # C:\Users\username\AppData\Roaming\VSCodium\User\settings.json

    # Declaring local variables
    user_conf_dir = makepath(user_appdata, "VSCodium", "User")
    user_conf_file = makepath(user_conf_dir, "settings.json")
    user_conf_content = r"""{
    "update.mode": "none",
    "update.showReleaseNotes": false,
    "update.enableWindowsBackgroundUpdates": false,
    "telemetry.enableCrashReporter": false,
    "telemetry.enableTelemetry": false,
    "typescript.surveys.enabled": false,
    "extensions.autoCheckUpdates": true,
    "extensions.autoUpdate": false
}"""

    user_conf_data = json.loads(user_conf_content.strip(","))
    if not isdir(user_conf_dir):
        mkdirs(user_conf_dir)
    if not isfile(user_conf_file):
        print("Creating: settings.json in: %s" % user_conf_dir)
        json_write_file(user_conf_file, user_conf_data)
    else:
        new_user_conf_data = json_load_file(user_conf_file)
        new_user_conf_data.update(user_conf_data)
        print("Updating: settings.json in: %s" % user_conf_dir)
        json_write_file(user_conf_file, new_user_conf_data)
